const fs = require('fs')

/**
 * 生成文件类型
 * @param fileName
 * @returns {*}
 */
exports.getFileType = (fileName) => {
  const suffix = fileName.substr(fileName.lastIndexOf(".")+1, fileName.length-1).toLowerCase()
  switch (suffix.toLowerCase()) {
    case "png":
    case "jpg":
    case "jpeg":
    case "gif":
    case "bmp":
      return "image"
    case "mp4":
    case "avi":
    case "m4v":
    case "wmv":
    case "rmvb":
      return "video"
    case "txt":
    case "text":
    case "md":
    case "markdown":
      return "text"
    default:
      return "text"
  }
}

/**
 * 删除文件或文件夹
 * @param path
 */
exports.deleteFolderRecursive = (path) => {
  let files = []
  if( fs.existsSync(path) ) {
    files = fs.readdirSync(path);
    files.forEach(function(file,index) {
      const curPath = path + "/" + file
      if(fs.statSync(curPath).isDirectory()) { // recurse
        deleteFolderRecursive(curPath);
      } else {
        fs.unlinkSync(curPath);
      }
    });
    fs.rmdirSync(path);
  }
}

/**
 * 从 request 获取参数
 * @param req
 * @param key
 */
exports.params = (req, key) => {
  if (!req || !key) {
    return null
  }
  return req.body[key] || req.query[key]
}